@@ -16,20 +16,16 @@ public:
 private:
     void initializeEngine(QQmlEngine *engine, const char *uri) override;
     
-    QString resolveFilePath(const QString &path) const
-    {
-#if defined(Q_OS_ANDROID)
-        return QStringLiteral(":/android_rcc_bundle/qml/org/mauikit/filebrowsing/") + path;
-#else
-        return baseUrl().toLocalFile() + QLatin1Char('/') + path;
-#endif
-    }
     QString resolveFileUrl(const QString &filePath) const
     {
 #if defined(Q_OS_ANDROID)
         return QStringLiteral("qrc:/android_rcc_bundle/qml/org/mauikit/filebrowsing/") + filePath;
+#else
+#ifdef QUICK_COMPILER
+        return QStringLiteral("qrc:/mauikit/filebrowsing/") + filePath;
 #else
         return baseUrl().toString() + QLatin1Char('/') + filePath;
+#endif
 #endif
     }
 };
