@@ -9,7 +9,7 @@
 #include <QDebug>
 #include <QSettings>
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID 
 #include <KConfig>
 #include <KConfigGroup>
 #endif
@@ -526,14 +526,12 @@ const FMH::MODEL FMStatic::getFileInfo(const KFileItem &kfile)
         {FMH::MODEL_KEY::HIDDEN, QVariant(kfile.isHidden()).toString()},
         {FMH::MODEL_KEY::IS_DIR, QVariant(kfile.isDir()).toString()},
         {FMH::MODEL_KEY::IS_FILE, QVariant(kfile.isFile()).toString()},
-        {FMH::MODEL_KEY::WRITABLE, QVariant(kfile.isWritable()).toString()},
-        {FMH::MODEL_KEY::READABLE, QVariant(kfile.isReadable()).toString()},
-        {FMH::MODEL_KEY::EXECUTABLE, QVariant(kfile.isDesktopFile()).toString()},
+//         {FMH::MODEL_KEY::WRITABLE, QVariant(kfile.isWritable()).toString()},
+//         {FMH::MODEL_KEY::READABLE, QVariant(kfile.isReadable()).toString()},
+//         {FMH::MODEL_KEY::EXECUTABLE, QVariant(kfile.isDesktopFile()).toString()},
         {FMH::MODEL_KEY::MIME, kfile.mimetype()},
-//         {FMH::MODEL_KEY::GROUP, kfile.group()},
         {FMH::MODEL_KEY::ICON, kfile.iconName()},
         {FMH::MODEL_KEY::SIZE, QString::number(kfile.size())},
-//         {FMH::MODEL_KEY::OWNER, kfile.user()},
         {FMH::MODEL_KEY::COUNT, kfile.isLocalFile() && kfile.isDir() ? QString::number(QDir(kfile.localPath()).count()) : "0"}};
         }
 #endif
@@ -564,9 +562,9 @@ const FMH::MODEL FMStatic::getFileInfo(const KFileItem &kfile)
             {FMH::MODEL_KEY::IS_FILE, QVariant(file.isFile()).toString()},
             {FMH::MODEL_KEY::HIDDEN, QVariant(file.isHidden()).toString()},
             {FMH::MODEL_KEY::IS_DIR, QVariant(file.isDir()).toString()},
-            {FMH::MODEL_KEY::WRITABLE, QVariant(file.isWritable()).toString()},
-            {FMH::MODEL_KEY::READABLE, QVariant(file.isReadable()).toString()},
-            {FMH::MODEL_KEY::EXECUTABLE, QVariant(file.suffix().endsWith(".desktop")).toString()},
+//             {FMH::MODEL_KEY::WRITABLE, QVariant(file.isWritable()).toString()},
+//             {FMH::MODEL_KEY::READABLE, QVariant(file.isReadable()).toString()},
+//             {FMH::MODEL_KEY::EXECUTABLE, QVariant(file.suffix().endsWith(".desktop")).toString()},
             {FMH::MODEL_KEY::ICON, getIconName(path)},
             {FMH::MODEL_KEY::SIZE, QString::number(file.size()) /*locale.formattedDataSize(file.size())*/},
             {FMH::MODEL_KEY::PATH, path.toString()},
